[LyX/master] Simplify KeyModifier

Yuriy Skalko yuriy.skalko at gmail.com
Mon Nov 30 08:14:40 UTC 2020


commit 89d05890bf264958863f318fa737e8337747ee8f
Author: Yuriy Skalko <yuriy.skalko at gmail.com>
Date:   Sun Nov 29 10:19:58 2020 +0200

    Simplify KeyModifier
---
 src/frontends/KeyModifier.h |   31 +++++++++----------------------
 1 files changed, 9 insertions(+), 22 deletions(-)

diff --git a/src/frontends/KeyModifier.h b/src/frontends/KeyModifier.h
index fba80be..b900b14 100644
--- a/src/frontends/KeyModifier.h
+++ b/src/frontends/KeyModifier.h
@@ -16,31 +16,18 @@
 
 namespace lyx {
 
-/// modifier key states
+/// Set of KeyModifierFlags
+typedef unsigned int KeyModifier;
 
-enum KeyModifier {
-	NoModifier       = 0, //< no modifiers held
-	ControlModifier  = 1, //< control button held
-	AltModifier      = 2, //< alt key held
-	ShiftModifier    = 4, //< shift key held
-	MetaModifier     = 8  //< meta key held
+/// modifier key states
+enum KeyModifierFlags : unsigned int {
+	NoModifier       = 0,      //< no modifiers held
+	ControlModifier  = 1 << 0, //< control button held
+	AltModifier      = 1 << 1, //< alt key held
+	ShiftModifier    = 1 << 2, //< shift key held
+	MetaModifier     = 1 << 3  //< meta key held
 };
 
-
-inline KeyModifier operator|(KeyModifier s1, KeyModifier s2)
-{
-	int const i1 = static_cast<int>(s1);
-	int const i2 = static_cast<int>(s2);
-	return static_cast<KeyModifier>(i1 | i2);
-}
-
-
-inline void operator|=(KeyModifier & s1, KeyModifier s2)
-{
-	s1 = static_cast<KeyModifier>(s1 | s2);
-}
-
-
 } // namespace lyx
 
 #endif // KEYMODIFIER_H


More information about the lyx-cvs mailing list